Module extractor
src2md
0.1.6
Module extractor
Module Items
Functions
In crate src2md
src2md
Module
extractor
Functions

extract_
from_
markdown
Extracts files from a Markdown file generated by src2md. Optionally takes a target root path to relocate the extracted files.